@@ -7,13 +7,14 @@ import argparse
 from typing import Optional, Dict, List
 from datetime import datetime
 
+import numpy as np
+
 import ray
 from ray import tune
 
 import hpogrid
 from hpogrid.components.defaults import *
 from hpogrid.utils import helper
-from hpogrid.components import environment_settings
 from hpogrid.idds_interface import idds_utils
 
 
@@ -117,8 +118,22 @@ class JobBuilder():
     @property
     def hyperparameters(self):
         return self._hyperparameters
+    
+    @property
+    def log_dir(self) -> str:
+        return self._log_dir
 
-
+    @log_dir.setter
+    def log_dir(self, val):
+        self._log_dir = val
+        if hpogrid.is_local_job() and (not os.path.isabs(val)):
+            project_path = helper.get_project_path(self.project_name)
+            if os.path.exists(project_path):
+                self._log_dir = os.path.join(project_path, val)
+        self._log_dir = helper.pretty_path(self._log_dir)
+            
+        
+            
     def reset(self):
         self.project_name = None
         # model configuration
@@ -137,7 +152,7 @@ class JobBuilder():
         self.num_trials = None
         self.max_concurrent = kDefaultMaxConcurrent
         self.verbose = False
-        self.log_dir = kDefaultLogDir
+        self._log_dir = kDefaultLogDir
         self.stop = kDefaultStopping
         self._resource = None
         # parameters for logging
@@ -277,15 +292,18 @@ class JobBuilder():
     def run(self) -> None:
             
         self._start_timestamp = start = time.time()
+        self._start_datetime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
 
+        # get model parameters
         if self.algorithm == 'tune':
-            tune_config_space = JobBuilder.get_search_space(self.search_space, algorithm='tune')
+            tune_config_space = self.get_search_space(self.search_space, algorithm='tune')
         else:
             tune_config_space = {}
 
         tune_config_space.update(self.model_param)
 
-        algorithm = JobBuilder.get_algorithm(
+        # get search algorithm
+        algorithm = self.get_algorithm(
             self.algorithm,
             self.metric,
             self.mode,
@@ -293,26 +311,32 @@ class JobBuilder():
             self.max_concurrent,
             **self.algorithm_param)
         
-    
-        scheduler = JobBuilder.get_scheduler(
+        # get trial scheduler
+        scheduler = self.get_scheduler(
             self.scheduler,
             self.metric,
             self.mode,
             self.search_space,
             **self.scheduler_param)
-
-        model = JobBuilder.get_model(self.model_script, self.model_name, self.scripts_path)
-
-        self._start_datetime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
-
-
+        
+        # get model
+        model = self.get_model(self.model_script, self.model_name, self.scripts_path)
+        
+        loggers = None
+        #loggers = self.get_loggers()
+        
         # save something to prevent looping job
         with open(kGridSiteMetadataFileName,'w') as output:
             json.dump({}, output)
+            
+        # HPO starts
         try:
+            
+            # extract input dataset if it is a tar file
+            # (for grid jobs only)
             extracted_files = []
-            if environment_settings.is_grid_job():
-                datadir = environment_settings.get_datadir()
+            if hpogrid.is_grid_job():
+                datadir = hpogrid.get_datadir()
                 extracted_files = helper.extract_tarball(datadir, datadir)
                 
             ray.init(include_dashboard=False,
@@ -327,12 +351,15 @@ class JobBuilder():
                 resources_per_trial=self.resource_per_trial,
                 verbose=self.verbose,
                 local_dir=self.log_dir,
+                loggers=loggers,
                 stop=self.stop,
-                sync_to_driver=False)
+                sync_to_driver=False,
+                global_checkpoint_period=np.inf)
         finally:
             ray.shutdown()
+            # remove the extracted tar files
             helper.remove_files(extracted_files)
-
+        
         end = time.time()
         self._total_time = float(end-start)
         self._end_datetime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
@@ -341,30 +368,47 @@ class JobBuilder():
         
         print("Best config: ", self.best_config)
         print("Time taken in seconds: ", self.total_time)
+        
+        print("INFO: Ray Tune log files are saved at {}".format(self.log_dir))
 
         df = analysis.dataframe()
 
         metadata = self.create_metadata(df)
         
-        metadata_path = os.path.join(hpogrid.get_workdir(), kGridSiteMetadataFileName)
+        metadata_path = self.get_metadata_path()
+        
         # save metadata
         with open(metadata_path,'w') as output:
-            print('INFO: Saved job metadata at {}'.format(metadata_path))
+            print('INFO: Job metadata is saved at {}'.format(metadata_path))
             json.dump(metadata, output, cls=helper.NpEncoder)
         
         # save idds output
-        if environment_settings.is_idds_job():
+        if hpogrid.is_idds_job():
             idds_utils.save_idds_output_from_metadata(metadata)
 
         # reset environment
-        environment_settings.reset()
+        hpogrid.reset()
+    
+    def get_loggers(self):
+        from ray.tune.logger import NoopLogger, MLFLowLogger
+        return [NoopLogger, MLFLowLogger]
+        
+    
+    def get_metadata_path(self):
+        base_path = hpogrid.get_workdir()
+        if hpogrid.is_local_job():
+            project_path = helper.get_project_path(self.project_name)
+            if os.path.exists(project_path):
+                base_path = project_path
+        metadata_path = os.path.join(base_path, kGridSiteMetadataFileName)
+        return metadata_path
     
     @classmethod
     def from_input(cls, config_input: [Dict, str],
                     search_points=None,
                     mode='local'):
         
-        environment_settings.setup(mode)
+        hpogrid.setup(mode)
         
         input_as_project = helper.is_project(config_input)
         config = helper.load_configuration(config_input)
@@ -401,7 +445,7 @@ class JobBuilder():
         
         
         # configuration for idds
-        if (not search_points) and environment_settings.is_idds_job():
+        if (not search_points) and hpogrid.is_idds_job():
             search_points = idds_utils.get_search_points()
         
         if search_points:
