@@ -129,9 +129,11 @@ class PandaTaskManager():
                 help='only show the task with the specified jeditaskid')
             parser.add_argument('-m', '--metadata', action='store_true',
                 help='print out the metadata of a task')
-            parser.add_argument('-s', '--sync', action='store_true',
+            parser.add_argument('-s', '--status', 
+                help='filter tasks by task status')
+            parser.add_argument('-y', '--sync', action='store_true',
                 help='force no caching on the PanDA server')
-            parser.add_argument('-r', '--range',
+            parser.add_argument('-r', '--taskid_range',
                 help='filter tasks by jeditaskid range')
             parser.add_argument('-o', '--output',
                 help='output result with the filename if specified')
@@ -162,12 +164,12 @@ class PandaTaskManager():
 
 
     def query_job_metadata(self, taskids):
-    	metadata = []
-    	pbar = tqdm(taskids)
-    	for tid in pbar:
-    		pbar.set_description("Processing taskid %s" % tid)
-    		metadata.append(Client.getUserJobMetadata(tid, verbose=0)[1])
-    	return metadata
+        metadata = []
+        pbar = tqdm(taskids)
+        for tid in pbar:
+            pbar.set_description("Processing taskid %s" % tid)
+            metadata.append(Client.getUserJobMetadata(tid, verbose=0)[1])
+        return metadata
 
     #deprecated
     def query_by_jeditaskid(self, taskids):
@@ -179,7 +181,6 @@ class PandaTaskManager():
         if not isinstance(taskids, list):
             taskids = [taskids]
         response = []
-        set_trace()
         pbar = tqdm(taskids)
         for tid in pbar:
             pbar.set_description("Processing taskid %s" % tid)
@@ -191,17 +192,20 @@ class PandaTaskManager():
 
 
     def query_tasks(self, taskname=None, jeditaskid=None, username=None, limit=1000,
-        status=None, superstatus=None, days=30, sync=False, metadata=False, **args):
+                    status=None, superstatus=None, days=30, sync=False, metadata=False, 
+                    taskid_range=None, **args):
         if username is None:
             username = self.pbook.username
-
+        
+        _status = status if not isinstance(status, list) else None
+        
         params = { 
         'json': 1,
         'limit':limit,
         'jeditaskid': jeditaskid,
         'username': username,
         'taskname': taskname,
-        'status': status,
+        'status': _status,
         'superstatus': superstatus,
         'days': days
         }
@@ -213,33 +217,41 @@ class PandaTaskManager():
         
         if metadata:
             params['extra'] = 'metastruct'
-            params['status'] = 'done'
         
 
         print('INFO: Showing only max {} tasks in last {} days.'
             ' One can set "--days N" to see tasks in last N days,'
             ' and "--limit M" to see at most M latest tasks'
             .format(limit, days))
-
         response = None
         req = self.get_request(kPanDA_TaskURL, params)
         response = self.get_response(req)
 
         n_jobs = len(response)
+        
+       # set_trace()
+        if taskid_range:
+            response = self.filter_range(response, taskid_range)
+        if isinstance(status, list):
+            response = self.filter_status(response, status)
+        
+        new_n_jobs = len(response)
         if metadata and (n_jobs > 100):
             print('INFO: Fetching metadata for {} jobs '
                 'which is greater than the maximum limit (100). '
+                'Number of jobs after filtering task id range and'
+                ' task status is: {}.'
                 'Need to fetch metadata individually which '
                 'will be slower...\n'
                 'TIPS: Try to filter tasks by their task names to '
                 'remove irrelevant tasks. For example, if your '
                 'tasks have names of the form user.USERNAME.'
                 'PROJECTNAME.SOMETHING.ELSE, then you can use '
-                '--taskname *.PROJECTNAME.* to filter jobs'.format(n_jobs))
+                '--taskname *.PROJECTNAME.* to filter jobs'.format(n_jobs,new_n_jobs))
             taskids = [res['jeditaskid'] for res in response]
             job_metadata_list = self.query_job_metadata(taskids)
             for task, job_metadata in zip(response, job_metadata_list):
-            	task['jobs_metadata'] = job_metadata
+                task['jobs_metadata'] = job_metadata
             """
             overflow_task_ids = [res['jeditaskid'] for res in response[100:]]
             params['limit'] = 100
@@ -285,6 +297,13 @@ class PandaTaskManager():
         else:
             datasets = [ds for ds in datasets if int(ds['jeditaskid']) in range(int(r[0]),int(r[1]))]   
         return datasets
+    
+    # filter task by status
+    def filter_status(self, datasets, status):
+        if not isinstance(status, list):
+            status = [status]
+        datasets = [ds for ds in datasets if ds.get('status', None) in status]
+        return datasets    
 
     def filter_datasets(self, datasets, col=kOutputColumns, out_type=list):
         df = pd.DataFrame(datasets)
@@ -310,10 +329,6 @@ class PandaTaskManager():
         print('INFO: Fetching PanDA Tasks...')
         datasets = self.query_tasks(**params)
 
-        # filter tasks by jetitaskid range
-        if args.range is not None:
-            datasets = self.filter_range(datasets, args.range) 
-
         if args.metadata:
             self.print_metadata(datasets)
         else:
