@@ -71,15 +71,18 @@ class HPOReport():
         return True
 
     def append(self, data, extras=None):
-        if not self.check_consistency(data):
-            return None
-        keys_to_save = ['start_datetime', 'start_timestamp',
-                        'end_datetime', 'task_time_s', 'best_config', 'result']
-        result = {key: data[key] for key in keys_to_save}
-        if extras:
-            for key in extras:
-                result[key] = extras[key]
-        self.data.append(result)
+        if not isinstance(data, list):
+            data = [data]
+        for d in data:
+            if not self.check_consistency(d):
+                return None
+            keys_to_save = ['start_datetime', 'start_timestamp',
+                            'end_datetime', 'task_time_s', 'best_config', 'result']
+            result = {key: d[key] for key in keys_to_save}
+            if extras:
+                for key in extras:
+                    result[key] = extras[key]
+            self.data.append(result)
 
     def _check_data(self):
         if not self.data:
@@ -245,8 +248,8 @@ class HPOTaskHandle(HPOReport):
 
     def display(self, args):
         params = vars(args)
-        params['status'] = 'done'
         params['metadata'] = True
+        params['status'] = ['finished', 'done']
         proj_name = params.pop('proj_name', '')
         outname = params.pop('outname', None)
         datasets = self.taskmgr.query_tasks(**params)
@@ -283,14 +286,17 @@ class HPOTaskHandle(HPOReport):
         metadata_list = []
         for dataset in datasets:
             metadata = self.extract_metadata(dataset)
+            # check if metadata is empty
             if not metadata:
                 continue
-            if not validate_job_metadata(metadata):
-                continue
-            if metadata['project_name'] != proj_name:
+            # check if it is a valid metadata generated by hpogrid
+            # and if the metadata corresponds to the project of concern
+            if not all( validate_job_metadata(data) and 
+                       data.get('project_name', None) == proj_name \
+                       for data in metadata):
                 continue
             filtered_datasets.append(dataset)
-            metadata_list.append(metadata)
+            metadata_list += metadata
         if len(filtered_datasets) == 0:
             print('INFO: No results found.')
             sys.exit(1)
@@ -304,14 +310,27 @@ class HPOTaskHandle(HPOReport):
 
     def extract_metadata(self, dataset):
         #set_trace()
+        metadata_list = []
         if 'jobs_metadata' in dataset:
-            keys = list(dataset['jobs_metadata'].keys())
-            if keys:
-                return dataset['jobs_metadata'][keys[0]]['user_job_metadata']
-            else:
-                return None
-        else:
-            return None
+            jobs_metadata = dataset['jobs_metadata']
+            # take care of general case where a job contains multiple sub-jobs
+            # which will return a list of metadata
+            if not isinstance(jobs_metadata, list):
+                jobs_metadata = [jobs_metadata]
+            for job_metadata in jobs_metadata:
+                if not isinstance(job_metadata, dict):
+                    raise ValueError('Invalid job metadata format')
+                keys = list(job_metadata.keys())
+                # skip empty metadata
+                if not keys:
+                    continue
+                metadata = job_metadata[keys[0]].get('user_job_metadata', None)
+                if metadata is not None:
+                    metadata_list.append(metadata)
+                else:
+                    print('WARNING: The key "user_job_metadata" not found in job metadata. '
+                          'Probably the format has changed. Skipping.')
+        return metadata_list
 
     def parse_datasets(self, datasets, proj_name, extra_columns=kDefaultExtraColumns):
         summary = []
@@ -319,7 +338,7 @@ class HPOTaskHandle(HPOReport):
 
         metric =  None
         mode = None
-
+        
         for dataset in valid_datasets:
             metadata = self.extract_metadata(dataset)
             extras = {}
