@@ -4,18 +4,16 @@ import json
 
 from hpogrid.components.defaults import *
 from hpogrid.components import validation
-from hpogrid.utils import stylus
-from hpogrid.configuration.configuration_base import ConfigurationBase, kConfigAction
+from hpogrid import ConfigurationBase
 
 class SearchSpaceConfiguration(ConfigurationBase):
 
-    def initialize(self):
-        self.description = 'Manage configuration for hyperparameter search space'
-        self.usage = 'hpogrid search_space <action> <config_name> <search_space_definition>'
-        self.config_type = 'search_space'
-        self.list_columns = ['Search Space Configuration']
-        self.show_columns = ['Hyperparameters', 'Search Space']  
-
+    config_type = 'search_space'
+    description = 'Manage configuration for hyperparameter search space'
+    usage = 'hpogrid search_space <action> <config_name> <search_space_definition>'
+    list_columns = ['Search Space Configuration']
+    show_columns = ['Hyperparameters', 'Search Space']  
+    json_interpreted = []
 
     def get_parser(self, action=None):
         parser = self.get_base_parser()               
